%% ReadMe

% The codes in this folder estimate a VAR with stochastic volatility using
% the algorithm of Carriero, Chan, Clark, and Marcellino (2021),
% Corrigendum to "Large Vector Autoregressions 
% with stochastic volatility and non-conjugate priors."
% The codes are organised as follows:

% Example_data.csv: data file of 20 US time series taken from the FRED-MD
% dataset. The data contain also calendar, series labels, and transformation
% codes. Note the transformations have already been applied so the csv file
% contains already transformed data. 

% Main_triangular.m
% this is the main code to run, it reads the data file and performs
% estimation. At the end of the MCMC loop, the code displays convergence
% diagnostics (optional, this can be shut down by setting
% Compute_diagnostics=0), the time series plots of estimated volatilities
% for the 20 variables, and the impulse responses to a federal funds rate
% shock. The code is set for a VAR with 13 lags and 1000 draws, which
% already produces acceptable convergence properties. 

% The main code calls the following subroutines:
% 1. CTA.m
% this is the new part of the corrected algorithm, which factorizes the 
% posterior in a way that makes computation N^2 faster. Note this can be 
% plugged in any existing MCMC loop. 

% 2. KSC.m
% this routine performs a draw for the volatilities using the Kim, Shephard
% and Chib algorithm. This can be substituted with any other code
% performing draws from the volatilities, and it is not essential to the
% speed improvements. 

% 3. Diagnostics.m
% this file contains subroutines to compute convergence diagnostics. These
% are routines from the coda library (by John Geweke for the Inefficiency
% factors and Brooks, S.P. and Gelman, A. (1998) for the PSR factors). 

% 4. vec.m
% function to vectorize a matrix Y into a vector y (stacking the columns)

% finally note that some parts of this code might require the Matlab
% statistical toolbox (but only for the graphs, not the estimation part)

